

files="Common/config.ml Doc/ccslc.1 Doc/ccslc.html"

prefix=/usr/local
exec_prefix=${prefix}
libdir=/home/tews/Privat/tmp/Ccslc/Lib/Pvs


echo writing files $files
for f in $files ; do
# echo sed -e "s%@mllibdir@%$libdir%" \< ${mlconfigfile}.in \> ${mlconfigfile}
   echo writing $f
   sed -e "s%@mllibdir@%$libdir%" < $f.in > $f
done
